# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class ContractQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "customer_id": "int",
        "customer_name": "str",
        "contract_id": "int",
        "contract_name": "str",
        "contract_type": "str",
        "active": "bool",
        "default": "bool",
        "taxable": "bool",
        "start_date": "datetime",
        "end_date": "datetime",
        "retainer_flat_fee_contract": "RetainerFlatFeeContractQueryDTO",
        "hourly_contract": "HourlyContractQueryDTO",
        "block_hours_contract": "BlockHoursContractQueryDTO",
        "block_money_contract": "BlockMoneyContractQueryDTO",
        "remote_monitoring_contract": "RemoteMonitoringContractQueryDTO",
        "online_backup_contract": "OnlineBackupContractQueryDTO",
        "project_one_time_fee_contract": "ProjectOneTimeFeeContractQueryDTO",
        "project_hourly_rate_contract": "ProjectHourlyRateContractQueryDTO",
    }

    attribute_map = {
        "customer_id": "CustomerID",
        "customer_name": "CustomerName",
        "contract_id": "ContractID",
        "contract_name": "ContractName",
        "contract_type": "ContractType",
        "active": "Active",
        "default": "Default",
        "taxable": "Taxable",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "retainer_flat_fee_contract": "RetainerFlatFeeContract",
        "hourly_contract": "HourlyContract",
        "block_hours_contract": "BlockHoursContract",
        "block_money_contract": "BlockMoneyContract",
        "remote_monitoring_contract": "RemoteMonitoringContract",
        "online_backup_contract": "OnlineBackupContract",
        "project_one_time_fee_contract": "ProjectOneTimeFeeContract",
        "project_hourly_rate_contract": "ProjectHourlyRateContract",
    }

    def __init__(
        self,
        customer_id=None,
        customer_name=None,
        contract_id=None,
        contract_name=None,
        contract_type=None,
        active=None,
        default=None,
        taxable=None,
        start_date=None,
        end_date=None,
        retainer_flat_fee_contract=None,
        hourly_contract=None,
        block_hours_contract=None,
        block_money_contract=None,
        remote_monitoring_contract=None,
        online_backup_contract=None,
        project_one_time_fee_contract=None,
        project_hourly_rate_contract=None,
        _configuration=None,
    ):  # noqa: E501
        """ContractQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer_id = None
        self._customer_name = None
        self._contract_id = None
        self._contract_name = None
        self._contract_type = None
        self._active = None
        self._default = None
        self._taxable = None
        self._start_date = None
        self._end_date = None
        self._retainer_flat_fee_contract = None
        self._hourly_contract = None
        self._block_hours_contract = None
        self._block_money_contract = None
        self._remote_monitoring_contract = None
        self._online_backup_contract = None
        self._project_one_time_fee_contract = None
        self._project_hourly_rate_contract = None
        self.discriminator = None

        if customer_id is not None:
            self.customer_id = customer_id
        if customer_name is not None:
            self.customer_name = customer_name
        if contract_id is not None:
            self.contract_id = contract_id
        if contract_name is not None:
            self.contract_name = contract_name
        if contract_type is not None:
            self.contract_type = contract_type
        if active is not None:
            self.active = active
        if default is not None:
            self.default = default
        if taxable is not None:
            self.taxable = taxable
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if retainer_flat_fee_contract is not None:
            self.retainer_flat_fee_contract = retainer_flat_fee_contract
        if hourly_contract is not None:
            self.hourly_contract = hourly_contract
        if block_hours_contract is not None:
            self.block_hours_contract = block_hours_contract
        if block_money_contract is not None:
            self.block_money_contract = block_money_contract
        if remote_monitoring_contract is not None:
            self.remote_monitoring_contract = remote_monitoring_contract
        if online_backup_contract is not None:
            self.online_backup_contract = online_backup_contract
        if project_one_time_fee_contract is not None:
            self.project_one_time_fee_contract = project_one_time_fee_contract
        if project_hourly_rate_contract is not None:
            self.project_hourly_rate_contract = project_hourly_rate_contract

    @property
    def customer_id(self):
        """Gets the customer_id of this ContractQueryDTO.  # noqa: E501


        :return: The customer_id of this ContractQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this ContractQueryDTO.


        :param customer_id: The customer_id of this ContractQueryDTO.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def customer_name(self):
        """Gets the customer_name of this ContractQueryDTO.  # noqa: E501


        :return: The customer_name of this ContractQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this ContractQueryDTO.


        :param customer_name: The customer_name of this ContractQueryDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def contract_id(self):
        """Gets the contract_id of this ContractQueryDTO.  # noqa: E501


        :return: The contract_id of this ContractQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this ContractQueryDTO.


        :param contract_id: The contract_id of this ContractQueryDTO.  # noqa: E501
        :type: int
        """

        self._contract_id = contract_id

    @property
    def contract_name(self):
        """Gets the contract_name of this ContractQueryDTO.  # noqa: E501


        :return: The contract_name of this ContractQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._contract_name

    @contract_name.setter
    def contract_name(self, contract_name):
        """Sets the contract_name of this ContractQueryDTO.


        :param contract_name: The contract_name of this ContractQueryDTO.  # noqa: E501
        :type: str
        """

        self._contract_name = contract_name

    @property
    def contract_type(self):
        """Gets the contract_type of this ContractQueryDTO.  # noqa: E501


        :return: The contract_type of this ContractQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._contract_type

    @contract_type.setter
    def contract_type(self, contract_type):
        """Sets the contract_type of this ContractQueryDTO.


        :param contract_type: The contract_type of this ContractQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "RetainerFlatFee",
            "BlockHours",
            "Hourly",
            "RemoteMonitoring",
            "BlockMoney",
            "ProjectOneTimeFee",
            "ProjectHourlyRate",
            "OnlineBackup",
        ]  # noqa: E501
        if self._configuration.client_side_validation and contract_type not in allowed_values:
            raise ValueError(
                "Invalid value for `contract_type` ({0}), must be one of {1}".format(  # noqa: E501
                    contract_type, allowed_values
                )
            )

        self._contract_type = contract_type

    @property
    def active(self):
        """Gets the active of this ContractQueryDTO.  # noqa: E501


        :return: The active of this ContractQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this ContractQueryDTO.


        :param active: The active of this ContractQueryDTO.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def default(self):
        """Gets the default of this ContractQueryDTO.  # noqa: E501


        :return: The default of this ContractQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this ContractQueryDTO.


        :param default: The default of this ContractQueryDTO.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def taxable(self):
        """Gets the taxable of this ContractQueryDTO.  # noqa: E501


        :return: The taxable of this ContractQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._taxable

    @taxable.setter
    def taxable(self, taxable):
        """Sets the taxable of this ContractQueryDTO.


        :param taxable: The taxable of this ContractQueryDTO.  # noqa: E501
        :type: bool
        """

        self._taxable = taxable

    @property
    def start_date(self):
        """Gets the start_date of this ContractQueryDTO.  # noqa: E501


        :return: The start_date of this ContractQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ContractQueryDTO.


        :param start_date: The start_date of this ContractQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ContractQueryDTO.  # noqa: E501


        :return: The end_date of this ContractQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ContractQueryDTO.


        :param end_date: The end_date of this ContractQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def retainer_flat_fee_contract(self):
        """Gets the retainer_flat_fee_contract of this ContractQueryDTO.  # noqa: E501


        :return: The retainer_flat_fee_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: RetainerFlatFeeContractQueryDTO
        """
        return self._retainer_flat_fee_contract

    @retainer_flat_fee_contract.setter
    def retainer_flat_fee_contract(self, retainer_flat_fee_contract):
        """Sets the retainer_flat_fee_contract of this ContractQueryDTO.


        :param retainer_flat_fee_contract: The retainer_flat_fee_contract of this ContractQueryDTO.  # noqa: E501
        :type: RetainerFlatFeeContractQueryDTO
        """

        self._retainer_flat_fee_contract = retainer_flat_fee_contract

    @property
    def hourly_contract(self):
        """Gets the hourly_contract of this ContractQueryDTO.  # noqa: E501


        :return: The hourly_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: HourlyContractQueryDTO
        """
        return self._hourly_contract

    @hourly_contract.setter
    def hourly_contract(self, hourly_contract):
        """Sets the hourly_contract of this ContractQueryDTO.


        :param hourly_contract: The hourly_contract of this ContractQueryDTO.  # noqa: E501
        :type: HourlyContractQueryDTO
        """

        self._hourly_contract = hourly_contract

    @property
    def block_hours_contract(self):
        """Gets the block_hours_contract of this ContractQueryDTO.  # noqa: E501


        :return: The block_hours_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: BlockHoursContractQueryDTO
        """
        return self._block_hours_contract

    @block_hours_contract.setter
    def block_hours_contract(self, block_hours_contract):
        """Sets the block_hours_contract of this ContractQueryDTO.


        :param block_hours_contract: The block_hours_contract of this ContractQueryDTO.  # noqa: E501
        :type: BlockHoursContractQueryDTO
        """

        self._block_hours_contract = block_hours_contract

    @property
    def block_money_contract(self):
        """Gets the block_money_contract of this ContractQueryDTO.  # noqa: E501


        :return: The block_money_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: BlockMoneyContractQueryDTO
        """
        return self._block_money_contract

    @block_money_contract.setter
    def block_money_contract(self, block_money_contract):
        """Sets the block_money_contract of this ContractQueryDTO.


        :param block_money_contract: The block_money_contract of this ContractQueryDTO.  # noqa: E501
        :type: BlockMoneyContractQueryDTO
        """

        self._block_money_contract = block_money_contract

    @property
    def remote_monitoring_contract(self):
        """Gets the remote_monitoring_contract of this ContractQueryDTO.  # noqa: E501


        :return: The remote_monitoring_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: RemoteMonitoringContractQueryDTO
        """
        return self._remote_monitoring_contract

    @remote_monitoring_contract.setter
    def remote_monitoring_contract(self, remote_monitoring_contract):
        """Sets the remote_monitoring_contract of this ContractQueryDTO.


        :param remote_monitoring_contract: The remote_monitoring_contract of this ContractQueryDTO.  # noqa: E501
        :type: RemoteMonitoringContractQueryDTO
        """

        self._remote_monitoring_contract = remote_monitoring_contract

    @property
    def online_backup_contract(self):
        """Gets the online_backup_contract of this ContractQueryDTO.  # noqa: E501


        :return: The online_backup_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: OnlineBackupContractQueryDTO
        """
        return self._online_backup_contract

    @online_backup_contract.setter
    def online_backup_contract(self, online_backup_contract):
        """Sets the online_backup_contract of this ContractQueryDTO.


        :param online_backup_contract: The online_backup_contract of this ContractQueryDTO.  # noqa: E501
        :type: OnlineBackupContractQueryDTO
        """

        self._online_backup_contract = online_backup_contract

    @property
    def project_one_time_fee_contract(self):
        """Gets the project_one_time_fee_contract of this ContractQueryDTO.  # noqa: E501


        :return: The project_one_time_fee_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: ProjectOneTimeFeeContractQueryDTO
        """
        return self._project_one_time_fee_contract

    @project_one_time_fee_contract.setter
    def project_one_time_fee_contract(self, project_one_time_fee_contract):
        """Sets the project_one_time_fee_contract of this ContractQueryDTO.


        :param project_one_time_fee_contract: The project_one_time_fee_contract of this ContractQueryDTO.  # noqa: E501
        :type: ProjectOneTimeFeeContractQueryDTO
        """

        self._project_one_time_fee_contract = project_one_time_fee_contract

    @property
    def project_hourly_rate_contract(self):
        """Gets the project_hourly_rate_contract of this ContractQueryDTO.  # noqa: E501


        :return: The project_hourly_rate_contract of this ContractQueryDTO.  # noqa: E501
        :rtype: ProjectHourlyRateContractQueryDTO
        """
        return self._project_hourly_rate_contract

    @project_hourly_rate_contract.setter
    def project_hourly_rate_contract(self, project_hourly_rate_contract):
        """Sets the project_hourly_rate_contract of this ContractQueryDTO.


        :param project_hourly_rate_contract: The project_hourly_rate_contract of this ContractQueryDTO.  # noqa: E501
        :type: ProjectHourlyRateContractQueryDTO
        """

        self._project_hourly_rate_contract = project_hourly_rate_contract

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ContractQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContractQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContractQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class TicketTimeEntriesSummaryQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"ticket_id": "int", "billable": "TicketDurationQueryDTO", "non_billable": "TicketDurationQueryDTO"}

    attribute_map = {"ticket_id": "TicketID", "billable": "Billable", "non_billable": "NonBillable"}

    def __init__(self, ticket_id=None, billable=None, non_billable=None, _configuration=None):  # noqa: E501
        """TicketTimeEntriesSummaryQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ticket_id = None
        self._billable = None
        self._non_billable = None
        self.discriminator = None

        if ticket_id is not None:
            self.ticket_id = ticket_id
        if billable is not None:
            self.billable = billable
        if non_billable is not None:
            self.non_billable = non_billable

    @property
    def ticket_id(self):
        """Gets the ticket_id of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501


        :return: The ticket_id of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._ticket_id

    @ticket_id.setter
    def ticket_id(self, ticket_id):
        """Sets the ticket_id of this TicketTimeEntriesSummaryQueryDTO.


        :param ticket_id: The ticket_id of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501
        :type: int
        """

        self._ticket_id = ticket_id

    @property
    def billable(self):
        """Gets the billable of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501


        :return: The billable of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501
        :rtype: TicketDurationQueryDTO
        """
        return self._billable

    @billable.setter
    def billable(self, billable):
        """Sets the billable of this TicketTimeEntriesSummaryQueryDTO.


        :param billable: The billable of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501
        :type: TicketDurationQueryDTO
        """

        self._billable = billable

    @property
    def non_billable(self):
        """Gets the non_billable of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501


        :return: The non_billable of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501
        :rtype: TicketDurationQueryDTO
        """
        return self._non_billable

    @non_billable.setter
    def non_billable(self, non_billable):
        """Sets the non_billable of this TicketTimeEntriesSummaryQueryDTO.


        :param non_billable: The non_billable of this TicketTimeEntriesSummaryQueryDTO.  # noqa: E501
        :type: TicketDurationQueryDTO
        """

        self._non_billable = non_billable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TicketTimeEntriesSummaryQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TicketTimeEntriesSummaryQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TicketTimeEntriesSummaryQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from atera_client.api_client import ApiClient


class ContactApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def contact_delete(self, contact_id, **kwargs):  # noqa: E501
        """Delete specified contact  # noqa: E501

        Deletes the contact. Requires the contact ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_delete(contact_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contact_delete_with_http_info(contact_id, **kwargs)  # noqa: E501
        else:
            (data) = self.contact_delete_with_http_info(contact_id, **kwargs)  # noqa: E501
            return data

    def contact_delete_with_http_info(self, contact_id, **kwargs):  # noqa: E501
        """Delete specified contact  # noqa: E501

        Deletes the contact. Requires the contact ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_delete_with_http_info(contact_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contact_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contact_delete" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contact_id' is set
        if self.api_client.client_side_validation and (
            "contact_id" not in params or params["contact_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `contact_id` when calling `contact_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "contact_id" in params:
            path_params["contactId"] = params["contact_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contacts/{contactId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def contact_get(self, **kwargs):  # noqa: E501
        """Find Contacts  # noqa: E501

        Accepts whole or partial emails / phone numbers. If partial, will return all contacts whose emails / phone numbers contain the input string.              <br />              Return Contact List  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param str search_options_email:
        :param str search_options_phone:
        :return: APIResultWrapperContactQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contact_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.contact_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def contact_get_with_http_info(self, **kwargs):  # noqa: E501
        """Find Contacts  # noqa: E501

        Accepts whole or partial emails / phone numbers. If partial, will return all contacts whose emails / phone numbers contain the input string.              <br />              Return Contact List  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param str search_options_email:
        :param str search_options_phone:
        :return: APIResultWrapperContactQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page", "search_options_email", "search_options_phone"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contact_get" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501
        if "search_options_email" in params:
            query_params.append(("searchOptions.email", params["search_options_email"]))  # noqa: E501
        if "search_options_phone" in params:
            query_params.append(("searchOptions.phone", params["search_options_phone"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contacts",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperContactQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def contact_get_0(self, contact_id, **kwargs):  # noqa: E501
        """Find specified contact  # noqa: E501

        Returns the specified contact. Requires the contact ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_get_0(contact_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :return: ContactQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contact_get_0_with_http_info(contact_id, **kwargs)  # noqa: E501
        else:
            (data) = self.contact_get_0_with_http_info(contact_id, **kwargs)  # noqa: E501
            return data

    def contact_get_0_with_http_info(self, contact_id, **kwargs):  # noqa: E501
        """Find specified contact  # noqa: E501

        Returns the specified contact. Requires the contact ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_get_0_with_http_info(contact_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :return: ContactQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contact_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contact_get_0" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contact_id' is set
        if self.api_client.client_side_validation and (
            "contact_id" not in params or params["contact_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `contact_id` when calling `contact_get_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "contact_id" in params:
            path_params["contactId"] = params["contact_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contacts/{contactId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContactQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def contact_post(self, contact, **kwargs):  # noqa: E501
        """Create contact  # noqa: E501

        Creates a new contact for an existing customer. Requires the customer ID or the customer name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_post(contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateContactDTO contact: Required - System Contact Object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contact_post_with_http_info(contact, **kwargs)  # noqa: E501
        else:
            (data) = self.contact_post_with_http_info(contact, **kwargs)  # noqa: E501
            return data

    def contact_post_with_http_info(self, contact, **kwargs):  # noqa: E501
        """Create contact  # noqa: E501

        Creates a new contact for an existing customer. Requires the customer ID or the customer name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_post_with_http_info(contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateContactDTO contact: Required - System Contact Object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contact"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contact_post" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contact' is set
        if self.api_client.client_side_validation and (
            "contact" not in params or params["contact"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `contact` when calling `contact_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contact" in params:
            body_params = params["contact"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contacts",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def contact_put(self, contact_id, contact, **kwargs):  # noqa: E501
        """Update specified contact  # noqa: E501

        Updates an existing contact. Requires the contact ID.              <br /><br />               The following fields are editable:              <br /><br />               First Name (Firstname)              <br />              Last Name (Lastname)              <br />               Job Title (JobTitle)              <br />              Is Contact Person (IsContactPerson)              <br />              In Ignore Mode (InIgnoreMode)              <br />              Phone (Phone)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_put(contact_id, contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :param UpdateContactDTO contact: Required - System Contact Object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contact_put_with_http_info(contact_id, contact, **kwargs)  # noqa: E501
        else:
            (data) = self.contact_put_with_http_info(contact_id, contact, **kwargs)  # noqa: E501
            return data

    def contact_put_with_http_info(self, contact_id, contact, **kwargs):  # noqa: E501
        """Update specified contact  # noqa: E501

        Updates an existing contact. Requires the contact ID.              <br /><br />               The following fields are editable:              <br /><br />               First Name (Firstname)              <br />              Last Name (Lastname)              <br />               Job Title (JobTitle)              <br />              Is Contact Person (IsContactPerson)              <br />              In Ignore Mode (InIgnoreMode)              <br />              Phone (Phone)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_put_with_http_info(contact_id, contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :param UpdateContactDTO contact: Required - System Contact Object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contact_id", "contact"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contact_put" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contact_id' is set
        if self.api_client.client_side_validation and (
            "contact_id" not in params or params["contact_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `contact_id` when calling `contact_put`")  # noqa: E501
        # verify the required parameter 'contact' is set
        if self.api_client.client_side_validation and (
            "contact" not in params or params["contact"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `contact` when calling `contact_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "contact_id" in params:
            path_params["contactId"] = params["contact_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contact" in params:
            body_params = params["contact"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contacts/{contactId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def contact_put_0(self, contact_id, contact, **kwargs):  # noqa: E501
        """Update specified contact  # noqa: E501

        Updates an existing contact. Requires the contact ID.              <br /><br />               The following fields are editable:              <br /><br />               First Name (Firstname)              <br />              Last Name (Lastname)              <br />               Job Title (JobTitle)              <br />              Is Contact Person (IsContactPerson)              <br />              In Ignore Mode (InIgnoreMode)              <br />              Phone (Phone)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_put_0(contact_id, contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :param UpdateContactDTO contact: Required - System Contact Object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contact_put_0_with_http_info(contact_id, contact, **kwargs)  # noqa: E501
        else:
            (data) = self.contact_put_0_with_http_info(contact_id, contact, **kwargs)  # noqa: E501
            return data

    def contact_put_0_with_http_info(self, contact_id, contact, **kwargs):  # noqa: E501
        """Update specified contact  # noqa: E501

        Updates an existing contact. Requires the contact ID.              <br /><br />               The following fields are editable:              <br /><br />               First Name (Firstname)              <br />              Last Name (Lastname)              <br />               Job Title (JobTitle)              <br />              Is Contact Person (IsContactPerson)              <br />              In Ignore Mode (InIgnoreMode)              <br />              Phone (Phone)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contact_put_0_with_http_info(contact_id, contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contact_id: Required - System Contact ID (required)
        :param UpdateContactDTO contact: Required - System Contact Object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contact_id", "contact"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contact_put_0" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contact_id' is set
        if self.api_client.client_side_validation and (
            "contact_id" not in params or params["contact_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `contact_id` when calling `contact_put_0`")  # noqa: E501
        # verify the required parameter 'contact' is set
        if self.api_client.client_side_validation and (
            "contact" not in params or params["contact"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `contact` when calling `contact_put_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "contact_id" in params:
            path_params["contactId"] = params["contact_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contact" in params:
            body_params = params["contact"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contacts/{contactId}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from atera_client.api_client import ApiClient


class TicketApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def ticket_delete(self, ticket_id, **kwargs):  # noqa: E501
        """Delete specified ticket  # noqa: E501

        Deletes the specified ticket. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_delete(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_delete_with_http_info(ticket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_delete_with_http_info(ticket_id, **kwargs)  # noqa: E501
            return data

    def ticket_delete_with_http_info(self, ticket_id, **kwargs):  # noqa: E501
        """Delete specified ticket  # noqa: E501

        Deletes the specified ticket. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_delete_with_http_info(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_delete" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `ticket_id` when calling `ticket_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_get(self, **kwargs):  # noqa: E501
        """Find tickets  # noqa: E501

        Returns a list of tickets.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id:
        :param str ticket_status:
        :return: APIResultWrapperTicketQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.ticket_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def ticket_get_with_http_info(self, **kwargs):  # noqa: E501
        """Find tickets  # noqa: E501

        Returns a list of tickets.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id:
        :param str ticket_status:
        :return: APIResultWrapperTicketQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page", "customer_id", "ticket_status"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_get" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501
        if "customer_id" in params:
            query_params.append(("customerId", params["customer_id"]))  # noqa: E501
        if "ticket_status" in params:
            query_params.append(("ticketStatus", params["ticket_status"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperTicketQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_get_0(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket  # noqa: E501

        Returns the specified ticket. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_0(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_get_0_with_http_info(ticket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_get_0_with_http_info(ticket_id, **kwargs)  # noqa: E501
            return data

    def ticket_get_0_with_http_info(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket  # noqa: E501

        Returns the specified ticket. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_0_with_http_info(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_get_0" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `ticket_id` when calling `ticket_get_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="TicketQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_get_billable_duration(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket (billable duration)  # noqa: E501

        Returns the specified ticket (billable duration). Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_billable_duration(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketDurationQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_get_billable_duration_with_http_info(ticket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_get_billable_duration_with_http_info(ticket_id, **kwargs)  # noqa: E501
            return data

    def ticket_get_billable_duration_with_http_info(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket (billable duration)  # noqa: E501

        Returns the specified ticket (billable duration). Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_billable_duration_with_http_info(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketDurationQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method ticket_get_billable_duration" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `ticket_id` when calling `ticket_get_billable_duration`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}/billableduration",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="TicketDurationQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_get_comments(self, ticket_id, **kwargs):  # noqa: E501
        """Find ticket comments list  # noqa: E501

        Returns the ticket comments. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_comments(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperTicketCommentQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_get_comments_with_http_info(ticket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_get_comments_with_http_info(ticket_id, **kwargs)  # noqa: E501
            return data

    def ticket_get_comments_with_http_info(self, ticket_id, **kwargs):  # noqa: E501
        """Find ticket comments list  # noqa: E501

        Returns the ticket comments. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_comments_with_http_info(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperTicketCommentQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id", "page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_get_comments" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `ticket_id` when calling `ticket_get_comments`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}/comments",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperTicketCommentQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_get_non_billable_duration(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket (non-billable duration)  # noqa: E501

        Returns the specified ticket (non-billable duration). Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_non_billable_duration(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketDurationQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_get_non_billable_duration_with_http_info(ticket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_get_non_billable_duration_with_http_info(ticket_id, **kwargs)  # noqa: E501
            return data

    def ticket_get_non_billable_duration_with_http_info(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket (non-billable duration)  # noqa: E501

        Returns the specified ticket (non-billable duration). Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_non_billable_duration_with_http_info(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketDurationQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method ticket_get_non_billable_duration" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `ticket_id` when calling `ticket_get_non_billable_duration`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}/nonbillableduration",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="TicketDurationQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_get_workhours(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket (workhours duration)  # noqa: E501

        Returns a record of the specified ticket's billable and non-billable workhours. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_workhours(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketTimeEntriesSummaryQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_get_workhours_with_http_info(ticket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_get_workhours_with_http_info(ticket_id, **kwargs)  # noqa: E501
            return data

    def ticket_get_workhours_with_http_info(self, ticket_id, **kwargs):  # noqa: E501
        """Find specified ticket (workhours duration)  # noqa: E501

        Returns a record of the specified ticket's billable and non-billable workhours. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_workhours_with_http_info(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :return: TicketTimeEntriesSummaryQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_get_workhours" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `ticket_id` when calling `ticket_get_workhours`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}/workhours",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="TicketTimeEntriesSummaryQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_get_workhours_records(self, ticket_id, **kwargs):  # noqa: E501
        """Find tickets (workhour list)  # noqa: E501

        Returns the ticket's workhours. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_workhours_records(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperTicketTimeEntriesQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_get_workhours_records_with_http_info(ticket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_get_workhours_records_with_http_info(ticket_id, **kwargs)  # noqa: E501
            return data

    def ticket_get_workhours_records_with_http_info(self, ticket_id, **kwargs):  # noqa: E501
        """Find tickets (workhour list)  # noqa: E501

        Returns the ticket's workhours. Requires the ticket ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_get_workhours_records_with_http_info(ticket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperTicketTimeEntriesQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id", "page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method ticket_get_workhours_records" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `ticket_id` when calling `ticket_get_workhours_records`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}/workhoursrecords",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperTicketTimeEntriesQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_post(self, ticket, **kwargs):  # noqa: E501
        """Create ticket  # noqa: E501

        Creates a new ticket. Requires the enduser contact ID, title, and description.              <br /><br />               If you wish to create a new enduser for the ticket then you need to provide:              <br /><br />               Contact first name (EndUserFirstName)              <br />               Contact last name (EndUserLastName)              <br />               Email (EndUserEmail)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_post(ticket, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTicketDTO ticket: Required - System Ticket object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_post_with_http_info(ticket, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_post_with_http_info(ticket, **kwargs)  # noqa: E501
            return data

    def ticket_post_with_http_info(self, ticket, **kwargs):  # noqa: E501
        """Create ticket  # noqa: E501

        Creates a new ticket. Requires the enduser contact ID, title, and description.              <br /><br />               If you wish to create a new enduser for the ticket then you need to provide:              <br /><br />               Contact first name (EndUserFirstName)              <br />               Contact last name (EndUserLastName)              <br />               Email (EndUserEmail)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_post_with_http_info(ticket, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTicketDTO ticket: Required - System Ticket object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_post" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket' is set
        if self.api_client.client_side_validation and (
            "ticket" not in params or params["ticket"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `ticket` when calling `ticket_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "ticket" in params:
            body_params = params["ticket"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_put(self, ticket_id, ticket, **kwargs):  # noqa: E501
        """Update specified ticket  # noqa: E501

        Updates an existing ticket. Requires the ticket ID.              <br /><br />               The following fields are editable:              <br /><br />               Ticket Title (TicketTitle)              <br />              Ticket Status (TicketStatus)              <br />               Ticket Type (TicketType)              <br />              Ticket Priority (TicketPriority)              <br />              Ticket Impact (TicketImpact)              <br />              Assigned Technician ID (TechnicianContactID)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_put(ticket_id, ticket, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param UpdateTicketDTO ticket: Required - System Ticket object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_put_with_http_info(ticket_id, ticket, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_put_with_http_info(ticket_id, ticket, **kwargs)  # noqa: E501
            return data

    def ticket_put_with_http_info(self, ticket_id, ticket, **kwargs):  # noqa: E501
        """Update specified ticket  # noqa: E501

        Updates an existing ticket. Requires the ticket ID.              <br /><br />               The following fields are editable:              <br /><br />               Ticket Title (TicketTitle)              <br />              Ticket Status (TicketStatus)              <br />               Ticket Type (TicketType)              <br />              Ticket Priority (TicketPriority)              <br />              Ticket Impact (TicketImpact)              <br />              Assigned Technician ID (TechnicianContactID)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_put_with_http_info(ticket_id, ticket, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param UpdateTicketDTO ticket: Required - System Ticket object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id", "ticket"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_put" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `ticket_id` when calling `ticket_put`")  # noqa: E501
        # verify the required parameter 'ticket' is set
        if self.api_client.client_side_validation and (
            "ticket" not in params or params["ticket"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `ticket` when calling `ticket_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "ticket" in params:
            body_params = params["ticket"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_put_0(self, ticket_id, ticket, **kwargs):  # noqa: E501
        """Update specified ticket  # noqa: E501

        Updates an existing ticket. Requires the ticket ID.              <br /><br />               The following fields are editable:              <br /><br />               Ticket Title (TicketTitle)              <br />              Ticket Status (TicketStatus)              <br />               Ticket Type (TicketType)              <br />              Ticket Priority (TicketPriority)              <br />              Ticket Impact (TicketImpact)              <br />              Assigned Technician ID (TechnicianContactID)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_put_0(ticket_id, ticket, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param UpdateTicketDTO ticket: Required - System Ticket object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_put_0_with_http_info(ticket_id, ticket, **kwargs)  # noqa: E501
        else:
            (data) = self.ticket_put_0_with_http_info(ticket_id, ticket, **kwargs)  # noqa: E501
            return data

    def ticket_put_0_with_http_info(self, ticket_id, ticket, **kwargs):  # noqa: E501
        """Update specified ticket  # noqa: E501

        Updates an existing ticket. Requires the ticket ID.              <br /><br />               The following fields are editable:              <br /><br />               Ticket Title (TicketTitle)              <br />              Ticket Status (TicketStatus)              <br />               Ticket Type (TicketType)              <br />              Ticket Priority (TicketPriority)              <br />              Ticket Impact (TicketImpact)              <br />              Assigned Technician ID (TechnicianContactID)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_put_0_with_http_info(ticket_id, ticket, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int ticket_id: Required - System Ticket ID (required)
        :param UpdateTicketDTO ticket: Required - System Ticket object (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["ticket_id", "ticket"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method ticket_put_0" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'ticket_id' is set
        if self.api_client.client_side_validation and (
            "ticket_id" not in params or params["ticket_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `ticket_id` when calling `ticket_put_0`")  # noqa: E501
        # verify the required parameter 'ticket' is set
        if self.api_client.client_side_validation and (
            "ticket" not in params or params["ticket"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `ticket` when calling `ticket_put_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "ticket_id" in params:
            path_params["ticketId"] = params["ticket_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "ticket" in params:
            body_params = params["ticket"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/{ticketId}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def ticket_track_status_modified(self, **kwargs):  # noqa: E501
        """Find resolved and closed tickets  # noqa: E501

        Returns a list of resolved and closed tickets.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_track_status_modified(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperTicketQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.ticket_track_status_modified_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.ticket_track_status_modified_with_http_info(**kwargs)  # noqa: E501
            return data

    def ticket_track_status_modified_with_http_info(self, **kwargs):  # noqa: E501
        """Find resolved and closed tickets  # noqa: E501

        Returns a list of resolved and closed tickets.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ticket_track_status_modified_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperTicketQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method ticket_track_status_modified" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/tickets/statusmodified",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperTicketQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from atera_client.api.agent_api import AgentApi
from atera_client.api.alert_api import AlertApi
from atera_client.api.billing_api import BillingApi
from atera_client.api.contact_api import ContactApi
from atera_client.api.contracts_api import ContractsApi
from atera_client.api.custom_values_api import CustomValuesApi
from atera_client.api.customer_api import CustomerApi
from atera_client.api.device_api import DeviceApi
from atera_client.api.knowledge_base_api import KnowledgeBaseApi
from atera_client.api.rates_api import RatesApi
from atera_client.api.ticket_api import TicketApi



# coding: utf-8

# flake8: noqa
"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from atera_client.models.api_result_wrapper_agent_query_dto import APIResultWrapperAgentQueryDTO
from atera_client.models.api_result_wrapper_alert_query_dto import APIResultWrapperAlertQueryDTO
from atera_client.models.api_result_wrapper_contact_query_dto import APIResultWrapperContactQueryDTO
from atera_client.models.api_result_wrapper_contract_query_dto import APIResultWrapperContractQueryDTO
from atera_client.models.api_result_wrapper_customer_query_dto import APIResultWrapperCustomerQueryDTO
from atera_client.models.api_result_wrapper_generic_device_query_dto import APIResultWrapperGenericDeviceQueryDTO
from atera_client.models.api_result_wrapper_http_device_query_dto import APIResultWrapperHttpDeviceQueryDTO
from atera_client.models.api_result_wrapper_invoice_query_dto import APIResultWrapperInvoiceQueryDTO
from atera_client.models.api_result_wrapper_knowledge_base_query_dto import APIResultWrapperKnowledgeBaseQueryDTO
from atera_client.models.api_result_wrapper_rate_query_dto import APIResultWrapperRateQueryDTO
from atera_client.models.api_result_wrapper_snmp_device_query_dto import APIResultWrapperSNMPDeviceQueryDTO
from atera_client.models.api_result_wrapper_tcp_device_query_dto import APIResultWrapperTcpDeviceQueryDTO
from atera_client.models.api_result_wrapper_ticket_comment_query_dto import APIResultWrapperTicketCommentQueryDTO
from atera_client.models.api_result_wrapper_ticket_query_dto import APIResultWrapperTicketQueryDTO
from atera_client.models.api_result_wrapper_ticket_time_entries_query_dto import (
    APIResultWrapperTicketTimeEntriesQueryDTO,
)
from atera_client.models.agent_query_dto import AgentQueryDTO
from atera_client.models.alert_query_dto import AlertQueryDTO
from atera_client.models.block_hours_contract_query_dto import BlockHoursContractQueryDTO
from atera_client.models.block_money_contract_query_dto import BlockMoneyContractQueryDTO
from atera_client.models.contact_details import ContactDetails
from atera_client.models.contact_query_dto import ContactQueryDTO
from atera_client.models.contacts_search_options import ContactsSearchOptions
from atera_client.models.contract_query_dto import ContractQueryDTO
from atera_client.models.create_alert_dto import CreateAlertDTO
from atera_client.models.create_contact_dto import CreateContactDTO
from atera_client.models.create_customer_attachment_dto import CreateCustomerAttachmentDTO
from atera_client.models.create_customer_dto import CreateCustomerDTO
from atera_client.models.create_customer_folder_dto import CreateCustomerFolderDTO
from atera_client.models.create_generic_dto import CreateGenericDTO
from atera_client.models.create_http_dto import CreateHttpDTO
from atera_client.models.create_product_expense_rate_dto import CreateProductExpenseRateDTO
from atera_client.models.create_snmpdtov1_v2 import CreateSNMPDTOV1V2
from atera_client.models.create_snmpdtov3 import CreateSNMPDTOV3
from atera_client.models.create_tcpdto import CreateTCPDTO
from atera_client.models.create_ticket_dto import CreateTicketDTO
from atera_client.models.created_device_res import CreatedDeviceRes
from atera_client.models.custom_field_query_dto import CustomFieldQueryDTO
from atera_client.models.custom_value_query_dto import CustomValueQueryDTO
from atera_client.models.customer_query_dto import CustomerQueryDTO
from atera_client.models.generic_device_query_dto import GenericDeviceQueryDTO
from atera_client.models.hourly_contract_query_dto import HourlyContractQueryDTO
from atera_client.models.http_device_query_dto import HttpDeviceQueryDTO
from atera_client.models.invoice_line_item_query_dto import InvoiceLineItemQueryDTO
from atera_client.models.invoice_query_dto import InvoiceQueryDTO
from atera_client.models.knowledge_base_query_dto import KnowledgeBaseQueryDTO
from atera_client.models.object import Object
from atera_client.models.online_backup_contract_query_dto import OnlineBackupContractQueryDTO
from atera_client.models.option_field_values import OptionFieldValues
from atera_client.models.port import Port
from atera_client.models.port_query_dto import PortQueryDTO
from atera_client.models.project_hourly_rate_contract_query_dto import ProjectHourlyRateContractQueryDTO
from atera_client.models.project_one_time_fee_contract_query_dto import ProjectOneTimeFeeContractQueryDTO
from atera_client.models.rate_query_dto import RateQueryDTO
from atera_client.models.remote_monitoring_contract_query_dto import RemoteMonitoringContractQueryDTO
from atera_client.models.result import Result
from atera_client.models.retainer_flat_fee_contract_query_dto import RetainerFlatFeeContractQueryDTO
from atera_client.models.snmp_device_query_dto import SNMPDeviceQueryDTO
from atera_client.models.set_custom_value_dto import SetCustomValueDTO
from atera_client.models.tcp_device_query_dto import TcpDeviceQueryDTO
from atera_client.models.ticket_comment_query_dto import TicketCommentQueryDTO
from atera_client.models.ticket_duration_query_dto import TicketDurationQueryDTO
from atera_client.models.ticket_query_dto import TicketQueryDTO
from atera_client.models.ticket_time_entries_query_dto import TicketTimeEntriesQueryDTO
from atera_client.models.ticket_time_entries_summary_query_dto import TicketTimeEntriesSummaryQueryDTO
from atera_client.models.update_contact_dto import UpdateContactDTO
from atera_client.models.update_customer_dto import UpdateCustomerDTO
from atera_client.models.update_product_expense_rate_dto import UpdateProductExpenseRateDTO
from atera_client.models.update_ticket_dto import UpdateTicketDTO



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class KnowledgeBaseQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "kbid": "int",
        "kb_timestamp": "datetime",
        "kb_context": "str",
        "kb_product": "str",
        "kb_rating_yes": "int",
        "kb_rating_no": "int",
        "kb_rating_views": "int",
        "kb_last_modified": "datetime",
        "kb_is_private": "bool",
        "kb_status": "int",
        "kb_priority": "int",
        "kb_keywords": "str",
        "kb_address": "str",
    }

    attribute_map = {
        "kbid": "KBID",
        "kb_timestamp": "KBTimestamp",
        "kb_context": "KBContext",
        "kb_product": "KBProduct",
        "kb_rating_yes": "KBRating_Yes",
        "kb_rating_no": "KBRating_No",
        "kb_rating_views": "KBRating_Views",
        "kb_last_modified": "KBLastModified",
        "kb_is_private": "KBIsPrivate",
        "kb_status": "KBStatus",
        "kb_priority": "KBPriority",
        "kb_keywords": "KBKeywords",
        "kb_address": "KBAddress",
    }

    def __init__(
        self,
        kbid=None,
        kb_timestamp=None,
        kb_context=None,
        kb_product=None,
        kb_rating_yes=None,
        kb_rating_no=None,
        kb_rating_views=None,
        kb_last_modified=None,
        kb_is_private=None,
        kb_status=None,
        kb_priority=None,
        kb_keywords=None,
        kb_address=None,
        _configuration=None,
    ):  # noqa: E501
        """KnowledgeBaseQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._kbid = None
        self._kb_timestamp = None
        self._kb_context = None
        self._kb_product = None
        self._kb_rating_yes = None
        self._kb_rating_no = None
        self._kb_rating_views = None
        self._kb_last_modified = None
        self._kb_is_private = None
        self._kb_status = None
        self._kb_priority = None
        self._kb_keywords = None
        self._kb_address = None
        self.discriminator = None

        if kbid is not None:
            self.kbid = kbid
        if kb_timestamp is not None:
            self.kb_timestamp = kb_timestamp
        if kb_context is not None:
            self.kb_context = kb_context
        if kb_product is not None:
            self.kb_product = kb_product
        if kb_rating_yes is not None:
            self.kb_rating_yes = kb_rating_yes
        if kb_rating_no is not None:
            self.kb_rating_no = kb_rating_no
        if kb_rating_views is not None:
            self.kb_rating_views = kb_rating_views
        if kb_last_modified is not None:
            self.kb_last_modified = kb_last_modified
        if kb_is_private is not None:
            self.kb_is_private = kb_is_private
        if kb_status is not None:
            self.kb_status = kb_status
        if kb_priority is not None:
            self.kb_priority = kb_priority
        if kb_keywords is not None:
            self.kb_keywords = kb_keywords
        if kb_address is not None:
            self.kb_address = kb_address

    @property
    def kbid(self):
        """Gets the kbid of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kbid of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._kbid

    @kbid.setter
    def kbid(self, kbid):
        """Sets the kbid of this KnowledgeBaseQueryDTO.


        :param kbid: The kbid of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: int
        """

        self._kbid = kbid

    @property
    def kb_timestamp(self):
        """Gets the kb_timestamp of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_timestamp of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._kb_timestamp

    @kb_timestamp.setter
    def kb_timestamp(self, kb_timestamp):
        """Sets the kb_timestamp of this KnowledgeBaseQueryDTO.


        :param kb_timestamp: The kb_timestamp of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._kb_timestamp = kb_timestamp

    @property
    def kb_context(self):
        """Gets the kb_context of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_context of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._kb_context

    @kb_context.setter
    def kb_context(self, kb_context):
        """Sets the kb_context of this KnowledgeBaseQueryDTO.


        :param kb_context: The kb_context of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: str
        """

        self._kb_context = kb_context

    @property
    def kb_product(self):
        """Gets the kb_product of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_product of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._kb_product

    @kb_product.setter
    def kb_product(self, kb_product):
        """Sets the kb_product of this KnowledgeBaseQueryDTO.


        :param kb_product: The kb_product of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: str
        """

        self._kb_product = kb_product

    @property
    def kb_rating_yes(self):
        """Gets the kb_rating_yes of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_rating_yes of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._kb_rating_yes

    @kb_rating_yes.setter
    def kb_rating_yes(self, kb_rating_yes):
        """Sets the kb_rating_yes of this KnowledgeBaseQueryDTO.


        :param kb_rating_yes: The kb_rating_yes of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: int
        """

        self._kb_rating_yes = kb_rating_yes

    @property
    def kb_rating_no(self):
        """Gets the kb_rating_no of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_rating_no of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._kb_rating_no

    @kb_rating_no.setter
    def kb_rating_no(self, kb_rating_no):
        """Sets the kb_rating_no of this KnowledgeBaseQueryDTO.


        :param kb_rating_no: The kb_rating_no of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: int
        """

        self._kb_rating_no = kb_rating_no

    @property
    def kb_rating_views(self):
        """Gets the kb_rating_views of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_rating_views of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._kb_rating_views

    @kb_rating_views.setter
    def kb_rating_views(self, kb_rating_views):
        """Sets the kb_rating_views of this KnowledgeBaseQueryDTO.


        :param kb_rating_views: The kb_rating_views of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: int
        """

        self._kb_rating_views = kb_rating_views

    @property
    def kb_last_modified(self):
        """Gets the kb_last_modified of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_last_modified of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._kb_last_modified

    @kb_last_modified.setter
    def kb_last_modified(self, kb_last_modified):
        """Sets the kb_last_modified of this KnowledgeBaseQueryDTO.


        :param kb_last_modified: The kb_last_modified of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._kb_last_modified = kb_last_modified

    @property
    def kb_is_private(self):
        """Gets the kb_is_private of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_is_private of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._kb_is_private

    @kb_is_private.setter
    def kb_is_private(self, kb_is_private):
        """Sets the kb_is_private of this KnowledgeBaseQueryDTO.


        :param kb_is_private: The kb_is_private of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: bool
        """

        self._kb_is_private = kb_is_private

    @property
    def kb_status(self):
        """Gets the kb_status of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_status of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._kb_status

    @kb_status.setter
    def kb_status(self, kb_status):
        """Sets the kb_status of this KnowledgeBaseQueryDTO.


        :param kb_status: The kb_status of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: int
        """

        self._kb_status = kb_status

    @property
    def kb_priority(self):
        """Gets the kb_priority of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_priority of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._kb_priority

    @kb_priority.setter
    def kb_priority(self, kb_priority):
        """Sets the kb_priority of this KnowledgeBaseQueryDTO.


        :param kb_priority: The kb_priority of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: int
        """

        self._kb_priority = kb_priority

    @property
    def kb_keywords(self):
        """Gets the kb_keywords of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_keywords of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._kb_keywords

    @kb_keywords.setter
    def kb_keywords(self, kb_keywords):
        """Sets the kb_keywords of this KnowledgeBaseQueryDTO.


        :param kb_keywords: The kb_keywords of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: str
        """

        self._kb_keywords = kb_keywords

    @property
    def kb_address(self):
        """Gets the kb_address of this KnowledgeBaseQueryDTO.  # noqa: E501


        :return: The kb_address of this KnowledgeBaseQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._kb_address

    @kb_address.setter
    def kb_address(self, kb_address):
        """Sets the kb_address of this KnowledgeBaseQueryDTO.


        :param kb_address: The kb_address of this KnowledgeBaseQueryDTO.  # noqa: E501
        :type: str
        """

        self._kb_address = kb_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(KnowledgeBaseQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KnowledgeBaseQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KnowledgeBaseQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class APIResultWrapperContactQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "items": "list[ContactQueryDTO]",
        "total_item_count": "int",
        "page": "int",
        "items_in_page": "int",
        "total_pages": "int",
        "prev_link": "str",
        "next_link": "str",
    }

    attribute_map = {
        "items": "items",
        "total_item_count": "totalItemCount",
        "page": "page",
        "items_in_page": "itemsInPage",
        "total_pages": "totalPages",
        "prev_link": "prevLink",
        "next_link": "nextLink",
    }

    def __init__(
        self,
        items=None,
        total_item_count=None,
        page=None,
        items_in_page=None,
        total_pages=None,
        prev_link=None,
        next_link=None,
        _configuration=None,
    ):  # noqa: E501
        """APIResultWrapperContactQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._items = None
        self._total_item_count = None
        self._page = None
        self._items_in_page = None
        self._total_pages = None
        self._prev_link = None
        self._next_link = None
        self.discriminator = None

        if items is not None:
            self.items = items
        if total_item_count is not None:
            self.total_item_count = total_item_count
        if page is not None:
            self.page = page
        if items_in_page is not None:
            self.items_in_page = items_in_page
        if total_pages is not None:
            self.total_pages = total_pages
        if prev_link is not None:
            self.prev_link = prev_link
        if next_link is not None:
            self.next_link = next_link

    @property
    def items(self):
        """Gets the items of this APIResultWrapperContactQueryDTO.  # noqa: E501


        :return: The items of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :rtype: list[ContactQueryDTO]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this APIResultWrapperContactQueryDTO.


        :param items: The items of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :type: list[ContactQueryDTO]
        """

        self._items = items

    @property
    def total_item_count(self):
        """Gets the total_item_count of this APIResultWrapperContactQueryDTO.  # noqa: E501


        :return: The total_item_count of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._total_item_count

    @total_item_count.setter
    def total_item_count(self, total_item_count):
        """Sets the total_item_count of this APIResultWrapperContactQueryDTO.


        :param total_item_count: The total_item_count of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :type: int
        """

        self._total_item_count = total_item_count

    @property
    def page(self):
        """Gets the page of this APIResultWrapperContactQueryDTO.  # noqa: E501

        The current page.  # noqa: E501

        :return: The page of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this APIResultWrapperContactQueryDTO.

        The current page.  # noqa: E501

        :param page: The page of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def items_in_page(self):
        """Gets the items_in_page of this APIResultWrapperContactQueryDTO.  # noqa: E501

        The size of the page.  # noqa: E501

        :return: The items_in_page of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._items_in_page

    @items_in_page.setter
    def items_in_page(self, items_in_page):
        """Sets the items_in_page of this APIResultWrapperContactQueryDTO.

        The size of the page.  # noqa: E501

        :param items_in_page: The items_in_page of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :type: int
        """

        self._items_in_page = items_in_page

    @property
    def total_pages(self):
        """Gets the total_pages of this APIResultWrapperContactQueryDTO.  # noqa: E501

        Total count of pages in query  # noqa: E501

        :return: The total_pages of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this APIResultWrapperContactQueryDTO.

        Total count of pages in query  # noqa: E501

        :param total_pages: The total_pages of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    @property
    def prev_link(self):
        """Gets the prev_link of this APIResultWrapperContactQueryDTO.  # noqa: E501

        Previous query url link (if exists)  # noqa: E501

        :return: The prev_link of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._prev_link

    @prev_link.setter
    def prev_link(self, prev_link):
        """Sets the prev_link of this APIResultWrapperContactQueryDTO.

        Previous query url link (if exists)  # noqa: E501

        :param prev_link: The prev_link of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :type: str
        """

        self._prev_link = prev_link

    @property
    def next_link(self):
        """Gets the next_link of this APIResultWrapperContactQueryDTO.  # noqa: E501

        Next query url link (if exists)  # noqa: E501

        :return: The next_link of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._next_link

    @next_link.setter
    def next_link(self, next_link):
        """Sets the next_link of this APIResultWrapperContactQueryDTO.

        Next query url link (if exists)  # noqa: E501

        :param next_link: The next_link of this APIResultWrapperContactQueryDTO.  # noqa: E501
        :type: str
        """

        self._next_link = next_link

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(APIResultWrapperContactQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, APIResultWrapperContactQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, APIResultWrapperContactQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class AlertQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "alert_id": "int",
        "code": "int",
        "source": "str",
        "title": "str",
        "severity": "str",
        "created": "datetime",
        "snoozed_end_date": "datetime",
        "device_guid": "str",
        "additional_info": "str",
        "archived": "bool",
        "alert_category_id": "str",
        "archived_date": "datetime",
        "ticket_id": "int",
        "alert_message": "str",
        "device_name": "str",
        "customer_id": "int",
        "customer_name": "str",
        "folder_id": "int",
        "polling_cycles_count": "int",
    }

    attribute_map = {
        "alert_id": "AlertID",
        "code": "Code",
        "source": "Source",
        "title": "Title",
        "severity": "Severity",
        "created": "Created",
        "snoozed_end_date": "SnoozedEndDate",
        "device_guid": "DeviceGuid",
        "additional_info": "AdditionalInfo",
        "archived": "Archived",
        "alert_category_id": "AlertCategoryID",
        "archived_date": "ArchivedDate",
        "ticket_id": "TicketID",
        "alert_message": "AlertMessage",
        "device_name": "DeviceName",
        "customer_id": "CustomerID",
        "customer_name": "CustomerName",
        "folder_id": "FolderID",
        "polling_cycles_count": "PollingCyclesCount",
    }

    def __init__(
        self,
        alert_id=None,
        code=None,
        source=None,
        title=None,
        severity=None,
        created=None,
        snoozed_end_date=None,
        device_guid=None,
        additional_info=None,
        archived=None,
        alert_category_id=None,
        archived_date=None,
        ticket_id=None,
        alert_message=None,
        device_name=None,
        customer_id=None,
        customer_name=None,
        folder_id=None,
        polling_cycles_count=None,
        _configuration=None,
    ):  # noqa: E501
        """AlertQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._alert_id = None
        self._code = None
        self._source = None
        self._title = None
        self._severity = None
        self._created = None
        self._snoozed_end_date = None
        self._device_guid = None
        self._additional_info = None
        self._archived = None
        self._alert_category_id = None
        self._archived_date = None
        self._ticket_id = None
        self._alert_message = None
        self._device_name = None
        self._customer_id = None
        self._customer_name = None
        self._folder_id = None
        self._polling_cycles_count = None
        self.discriminator = None

        if alert_id is not None:
            self.alert_id = alert_id
        if code is not None:
            self.code = code
        if source is not None:
            self.source = source
        if title is not None:
            self.title = title
        if severity is not None:
            self.severity = severity
        if created is not None:
            self.created = created
        if snoozed_end_date is not None:
            self.snoozed_end_date = snoozed_end_date
        if device_guid is not None:
            self.device_guid = device_guid
        if additional_info is not None:
            self.additional_info = additional_info
        if archived is not None:
            self.archived = archived
        if alert_category_id is not None:
            self.alert_category_id = alert_category_id
        if archived_date is not None:
            self.archived_date = archived_date
        if ticket_id is not None:
            self.ticket_id = ticket_id
        if alert_message is not None:
            self.alert_message = alert_message
        if device_name is not None:
            self.device_name = device_name
        if customer_id is not None:
            self.customer_id = customer_id
        if customer_name is not None:
            self.customer_name = customer_name
        if folder_id is not None:
            self.folder_id = folder_id
        if polling_cycles_count is not None:
            self.polling_cycles_count = polling_cycles_count

    @property
    def alert_id(self):
        """Gets the alert_id of this AlertQueryDTO.  # noqa: E501


        :return: The alert_id of this AlertQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._alert_id

    @alert_id.setter
    def alert_id(self, alert_id):
        """Sets the alert_id of this AlertQueryDTO.


        :param alert_id: The alert_id of this AlertQueryDTO.  # noqa: E501
        :type: int
        """

        self._alert_id = alert_id

    @property
    def code(self):
        """Gets the code of this AlertQueryDTO.  # noqa: E501


        :return: The code of this AlertQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this AlertQueryDTO.


        :param code: The code of this AlertQueryDTO.  # noqa: E501
        :type: int
        """

        self._code = code

    @property
    def source(self):
        """Gets the source of this AlertQueryDTO.  # noqa: E501


        :return: The source of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this AlertQueryDTO.


        :param source: The source of this AlertQueryDTO.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def title(self):
        """Gets the title of this AlertQueryDTO.  # noqa: E501


        :return: The title of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this AlertQueryDTO.


        :param title: The title of this AlertQueryDTO.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def severity(self):
        """Gets the severity of this AlertQueryDTO.  # noqa: E501


        :return: The severity of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this AlertQueryDTO.


        :param severity: The severity of this AlertQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Information", "Warning", "Critical"]  # noqa: E501
        if self._configuration.client_side_validation and severity not in allowed_values:
            raise ValueError(
                "Invalid value for `severity` ({0}), must be one of {1}".format(severity, allowed_values)  # noqa: E501
            )

        self._severity = severity

    @property
    def created(self):
        """Gets the created of this AlertQueryDTO.  # noqa: E501


        :return: The created of this AlertQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this AlertQueryDTO.


        :param created: The created of this AlertQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def snoozed_end_date(self):
        """Gets the snoozed_end_date of this AlertQueryDTO.  # noqa: E501


        :return: The snoozed_end_date of this AlertQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._snoozed_end_date

    @snoozed_end_date.setter
    def snoozed_end_date(self, snoozed_end_date):
        """Sets the snoozed_end_date of this AlertQueryDTO.


        :param snoozed_end_date: The snoozed_end_date of this AlertQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._snoozed_end_date = snoozed_end_date

    @property
    def device_guid(self):
        """Gets the device_guid of this AlertQueryDTO.  # noqa: E501


        :return: The device_guid of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._device_guid

    @device_guid.setter
    def device_guid(self, device_guid):
        """Sets the device_guid of this AlertQueryDTO.


        :param device_guid: The device_guid of this AlertQueryDTO.  # noqa: E501
        :type: str
        """

        self._device_guid = device_guid

    @property
    def additional_info(self):
        """Gets the additional_info of this AlertQueryDTO.  # noqa: E501


        :return: The additional_info of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this AlertQueryDTO.


        :param additional_info: The additional_info of this AlertQueryDTO.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def archived(self):
        """Gets the archived of this AlertQueryDTO.  # noqa: E501


        :return: The archived of this AlertQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this AlertQueryDTO.


        :param archived: The archived of this AlertQueryDTO.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    @property
    def alert_category_id(self):
        """Gets the alert_category_id of this AlertQueryDTO.  # noqa: E501


        :return: The alert_category_id of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._alert_category_id

    @alert_category_id.setter
    def alert_category_id(self, alert_category_id):
        """Sets the alert_category_id of this AlertQueryDTO.


        :param alert_category_id: The alert_category_id of this AlertQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Hardware", "Disk", "Availability", "Performance", "Exchange", "General"]  # noqa: E501
        if self._configuration.client_side_validation and alert_category_id not in allowed_values:
            raise ValueError(
                "Invalid value for `alert_category_id` ({0}), must be one of {1}".format(  # noqa: E501
                    alert_category_id, allowed_values
                )
            )

        self._alert_category_id = alert_category_id

    @property
    def archived_date(self):
        """Gets the archived_date of this AlertQueryDTO.  # noqa: E501


        :return: The archived_date of this AlertQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_date

    @archived_date.setter
    def archived_date(self, archived_date):
        """Sets the archived_date of this AlertQueryDTO.


        :param archived_date: The archived_date of this AlertQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._archived_date = archived_date

    @property
    def ticket_id(self):
        """Gets the ticket_id of this AlertQueryDTO.  # noqa: E501


        :return: The ticket_id of this AlertQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._ticket_id

    @ticket_id.setter
    def ticket_id(self, ticket_id):
        """Sets the ticket_id of this AlertQueryDTO.


        :param ticket_id: The ticket_id of this AlertQueryDTO.  # noqa: E501
        :type: int
        """

        self._ticket_id = ticket_id

    @property
    def alert_message(self):
        """Gets the alert_message of this AlertQueryDTO.  # noqa: E501


        :return: The alert_message of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._alert_message

    @alert_message.setter
    def alert_message(self, alert_message):
        """Sets the alert_message of this AlertQueryDTO.


        :param alert_message: The alert_message of this AlertQueryDTO.  # noqa: E501
        :type: str
        """

        self._alert_message = alert_message

    @property
    def device_name(self):
        """Gets the device_name of this AlertQueryDTO.  # noqa: E501


        :return: The device_name of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this AlertQueryDTO.


        :param device_name: The device_name of this AlertQueryDTO.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def customer_id(self):
        """Gets the customer_id of this AlertQueryDTO.  # noqa: E501


        :return: The customer_id of this AlertQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this AlertQueryDTO.


        :param customer_id: The customer_id of this AlertQueryDTO.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def customer_name(self):
        """Gets the customer_name of this AlertQueryDTO.  # noqa: E501


        :return: The customer_name of this AlertQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this AlertQueryDTO.


        :param customer_name: The customer_name of this AlertQueryDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def folder_id(self):
        """Gets the folder_id of this AlertQueryDTO.  # noqa: E501


        :return: The folder_id of this AlertQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this AlertQueryDTO.


        :param folder_id: The folder_id of this AlertQueryDTO.  # noqa: E501
        :type: int
        """

        self._folder_id = folder_id

    @property
    def polling_cycles_count(self):
        """Gets the polling_cycles_count of this AlertQueryDTO.  # noqa: E501


        :return: The polling_cycles_count of this AlertQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._polling_cycles_count

    @polling_cycles_count.setter
    def polling_cycles_count(self, polling_cycles_count):
        """Sets the polling_cycles_count of this AlertQueryDTO.


        :param polling_cycles_count: The polling_cycles_count of this AlertQueryDTO.  # noqa: E501
        :type: int
        """

        self._polling_cycles_count = polling_cycles_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AlertQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlertQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AlertQueryDTO):
            return True

        return self.to_dict() != other.to_dict()
